2020-04-25 tangible ai qary dialog coach companion nutrition mindfulness ita daki mas

Based on the *ita daki mas* tradition of discussing a meal as you're sitting down to eat. It's the only time a phone is allowed at the table, to google anything that interests both people. One person asks the other to do the googling. You don't google for what you are interested in: Where do eggs come from? How are pigs raised?

ita daki mas = I humbly receive, I am ready to eat [ref](https://mymemory.translated.net/en/Japanese/English/ita-daki-mas)

... when the greeting conversation stalls and the user wants to chitchat:

qary: What did you have for dinner tonight?
hobs: sourdough and grilled cheese
qary.1: Did you know that lactic acid from lactobacillus bacteria in the dough is what makes sourdough sour? [ref](en.wikipedia.org/wiki/Sourdough%20bread)
qary.2: Did you know that lactobacillus bacteria and yeast live in symbiosis inside the dough? They work together to metabolize the starches into sugar, breathing out carbon dioxide. These carbon dioxide bubbles cause the bread to rise in the oven?
qary.3: Did you know that the Morocco equivalent of sourdough starter is a similar homemade leavening called *khmira beldia*. The Moroccan version of sourdough starter tends to be less sour and less bubbly.
qary.4: Did you know that cheese is one of the most resource intensive forms of protein and fat? It's as harmful to the [environment|animal wellbeing] as beef.

